==> haskell-co-log-core-0.3.2.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-co-log-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 co-log-core
version:              0.3.2.2
visibility:           public
id:                   co-log-core-0.3.2.2-9QCpr9Zeb9TL0WHJGe73ys
key:                  co-log-core-0.3.2.2-9QCpr9Zeb9TL0WHJGe73ys
license:              MPL-2.0
copyright:            2018-2020 Kowainik, 2021-2024 Co-Log
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/co-log/co-log-core
synopsis:             Composable Contravariant Comonadic Logging Library
description:
    This package provides core types and functions to work with the @LogAction@ data type which is both simple and powerful.

    @
    __newtype__ LogAction m msg = LogAction
    \    { unLogAction :: msg -> m ()
    \    }
    @

    The ideas behind this package are described in the following blog post:

    * [co-log: Composable Contravariant Combinatorial Comonadic Configurable Convenient Logging](https://kowainik.github.io/posts/2018-09-25-co-log)

    See the following packages for different implementations based on @co-log-core@:

    * [co-log](http://hackage.haskell.org/package/co-log): taggless final implementations.
    * [co-log-polysemy](http://hackage.haskell.org/package/co-log-polysemy): extensible
    effects implementation based on @polysemy@.

category:             Logging, Contravariant, Comonad
abi:                  ac095b9979530b5df396267afa60bcdb
exposed:              True
exposed-modules:
    Colog.Core Colog.Core.Action Colog.Core.Class Colog.Core.IO
    Colog.Core.Severity

import-dirs:          /usr/lib/ghc-9.2.8/site-local/co-log-core-0.3.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/co-log-core-0.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-co-log-core
hs-libraries:         HSco-log-core-0.3.2.2-9QCpr9Zeb9TL0WHJGe73ys
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-co-log-core/html/co-log-core.haddock
haddock-html:         /usr/share/doc/haskell-co-log-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-co-log-core-0.3.2.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-co-log-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 co-log-core
version:              0.3.2.3
visibility:           public
id:                   co-log-core-0.3.2.3-JxRWBSdKKZ2EtNQuUOyyhS
key:                  co-log-core-0.3.2.3-JxRWBSdKKZ2EtNQuUOyyhS
license:              MPL-2.0
copyright:            2018-2020 Kowainik, 2021-2025 Co-Log
maintainer:           Co-Log <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/co-log/co-log-core
synopsis:             Composable Contravariant Comonadic Logging Library
description:
    This package provides core types and functions to work with the @LogAction@ data type which is both simple and powerful.

    @
    __newtype__ LogAction m msg = LogAction
    \    { unLogAction :: msg -> m ()
    \    }
    @

    The ideas behind this package are described in the following blog post:

    * [co-log: Composable Contravariant Combinatorial Comonadic Configurable Convenient Logging](https://kowainik.github.io/posts/2018-09-25-co-log)

    See the following packages for different implementations based on @co-log-core@:

    * [co-log](http://hackage.haskell.org/package/co-log): taggless final implementations.
    * [co-log-polysemy](http://hackage.haskell.org/package/co-log-polysemy): extensible
    effects implementation based on @polysemy@.

category:             Logging, Contravariant, Comonad
abi:                  c9369f3d2ab06707edcc8b28eaae6dbf
exposed:              True
exposed-modules:
    Colog.Core Colog.Core.Action Colog.Core.Class Colog.Core.IO
    Colog.Core.Severity

import-dirs:          /usr/lib/ghc-9.2.8/site-local/co-log-core-0.3.2.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/co-log-core-0.3.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-co-log-core
hs-libraries:         HSco-log-core-0.3.2.3-JxRWBSdKKZ2EtNQuUOyyhS
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-co-log-core/html/co-log-core.haddock
haddock-html:         /usr/share/doc/haskell-co-log-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
